==> ark-4.11.4.tar.xz: ark-4.11.4/plugins/libarchive/kerfuffle_libarchive.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_libarchive
X-KDE-PluginInfo-Author=Henrique Pinto
X-KDE-PluginInfo-Email=henrique.pinto@kdemail.net
X-KDE-PluginInfo-Name=kerfuffle_libarchive
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=BSD
X-KDE-Priority=100
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
Name=kerfuffle_libarchive
Name[ar]=kerfuffle_libarchive
Name[ast]=kerfuffle_libarchive
Name[bg]=kerfuffle_libarchive
Name[bs]=kerfuffle_libarchive
Name[ca]=kerfuffle_libarchive
Name[ca@valencia]=kerfuffle_libarchive
Name[cs]=kerfuffle_libarchive
Name[da]=kerfuffle_libarchive
Name[de]=kerfuffle_libarchive
Name[el]=kerfuffle_libarchive
Name[en_GB]=kerfuffle_libarchive
Name[es]=kerfuffle_libarchive
Name[et]=kerfuffle_libarchive
Name[eu]=kerfuffle_libarchive
Name[fi]=kerfuffle_libarchive
Name[fr]=kerfuffle_libarchive
Name[ga]=kerfuffle_libarchive
Name[gl]=kerfuffle_libarchive
Name[he]=kerfuffle_libarchive
Name[hne]=करफुफल_लिबआर्काइव
Name[hr]=kerfuffle_libarchive
Name[hu]=kerfuffle_libarchive
Name[ia]=kerfuffle_libarchive
Name[id]=kerfuffle_libarchive
Name[it]=kerfuffle_libarchive
Name[ja]=kerfuffle_libarchive
Name[kk]=kerfuffle_libarchive
Name[km]=kerfuffle_libarchive
Name[ko]=kerfuffle_libarchive
Name[lt]=kerfuffle_libarchive
Name[lv]=kerfuffle_libarchive
Name[mr]=कर्फफल_लिब-संग्रह
Name[nb]=kerfuffle_libarchive
Name[nds]=kerfuffle_libarchive
Name[nl]=kerfuffle_libarchive
Name[nn]=kerfuffle_libarchive
Name[pa]=kerfuffle_libarchive
Name[pl]=kerfuffle_libarchive
Name[pt]=kerfuffle_libarchive
Name[pt_BR]=kerfuffle_libarchive
Name[ro]=kerfuffle_libarchive
Name[ru]=kerfuffle_libarchive
Name[sk]=kerfuffle_libarchive
Name[sl]=kerfuffle_libarchive
Name[sq]=kerfuffle_libarchive
Name[sr]=kerfuffle_libarchive
Name[sr@ijekavian]=kerfuffle_libarchive
Name[sr@ijekavianlatin]=kerfuffle_libarchive
Name[sr@latin]=kerfuffle_libarchive
Name[sv]=Kerfuffle Libarchive
Name[ta]=கெர்ஃபஃபில் லிப்ஆர்கைவ்
Name[th]=kerfuffle_libarchive
Name[tr]=kerfuffle_libarchive
Name[uk]=kerfuffle_libarchive
Name[wa]=kerfuffle_libarchive
Name[x-test]=xxkerfuffle_libarchivexx
Name[zh_CN]=kerfuffle_libarchive
Name[zh_TW]=kerfuffle_libarchive
Comment=LibArchive Plugin for Kerfuffle
Comment[ar]=LibArchive ملحق لـ Kerfuffle
Comment[ast]=Aplicación LibArchive pa Kerfuffle
Comment[bg]=Приставка LibArchive за Kerfuffle
Comment[bs]=Priključak libarchive za Kerfafl
Comment[ca]=Connector del LibArchive pel Kerfuffle
Comment[ca@valencia]=Connector del LibArchive pel Kerfuffle
Comment[cs]=LibArchive modul pro Kerfuffle
Comment[da]=LibArchive-plugin til Kerfuffle
Comment[de]=LibArchive-Modul für Kerfuffle
Comment[el]=πρόσθετο LibArchive για τη Kerfuffle
Comment[en_GB]=LibArchive Plugin for Kerfuffle
Comment[es]=Complemento LibArchive para Kerfuffle
Comment[et]=Kerfuffle'i LibArchive plugin
Comment[eu]=Kerfuffle-rentzako LibArchive Plugina
Comment[fi]=LibArchive-pakkaustuki
Comment[fr]=Module externe « LibArchive » pour Kerfuffle
Comment[ga]=Breiseán LibArchive le haghaidh Kerfuffle
Comment[gl]=Extensión de libarchive para Kerfuffle
Comment[he]=תוסף LibArchive  עבור Kerfuffle
Comment[hne]=करफुफल बर लिबआर्काइव प्लगइन
Comment[hr]=Priključak LibArchive za Kerfuffle
Comment[hu]=LibArchive Kerfuffle-modul
Comment[ia]=Plugin de Libarchive per Kerfuffle
Comment[id]=Pengaya LibArchive untuk Kerfuffle
Comment[it]=Estensione LibArchive per Kerfuffle
Comment[ja]=Kerfuffle のための LibArchive プラグイン
Comment[kk]=Kerfuffle-ге арналған LibArchive плагині
Comment[km]=កម្មវិធី​ជំនួយ LibArchive សម្រាប់ Kerfuffle
Comment[ko]=Kerfuffle을 위한 LibArchive 플러그인
Comment[lt]=LibArchive Kerfuffle priedas
Comment[lv]=Kerfuffle LibArchive spraudnis
Comment[mr]=कर्फफल करिता लिब-संग्रह प्लगइन
Comment[nb]=LibArchive programtillegg for Kerfuffle
Comment[nds]=LibArchive-Moduul för Kerfuffle
Comment[nl]=LibArchive-plug-in voor Kerfuffle
Comment[nn]=LibArchive-programtillegg til Kerfuffle
Comment[pl]=Wtyczka libArchive dla Kerfuffle
Comment[pt]='Plugin' de LibArchive para o Kerfuffle
Comment[pt_BR]=Plugin LibArchive para a Kerfuffle
Comment[ro]=Modul LibArchive pentru Kerfuffle
Comment[ru]=Модуль LibArchive для Kerfuffle
Comment[sk]=LibArchive modul pre Kerfuffle
Comment[sl]=Vstavek LibArchive za Kerfuffle
Comment[sq]=LibArchive Plugin për Kerfuffle
Comment[sr]=Прикључак libarchive за Керфафл
Comment[sr@ijekavian]=Прикључак libarchive за Керфафл
Comment[sr@ijekavianlatin]=Priključak libarchive za Kerfuffle
Comment[sr@latin]=Priključak libarchive za Kerfuffle
Comment[sv]=Libarchive-insticksprogram för Kerfuffle
Comment[ta]=கெர்ஃபஃபில் க்கு லிப்ஆர்கைவ் சொருகி
Comment[th]=ส่วนเสริมของ Kerfuffle สำหรับใช้งานไลบรารี LibArchive
Comment[tr]=Kerfuffle için LibArchive eklentisi
Comment[uk]=Додаток LibArchive для Kerfuffle
Comment[x-test]=xxLibArchive Plugin for Kerfufflexx
Comment[zh_CN]=Kerfuffle 的 LibArchive 插件
Comment[zh_TW]=Kerfuffle 的 LibArchive 外掛程式
MimeType=@SUPPORTED_LIBARCHIVE_READWRITE_MIMETYPES@

==> ark_4.13.3.orig.tar.xz: ark-4.13.3/plugins/libarchive/kerfuffle_libarchive.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_libarchive
X-KDE-PluginInfo-Author=Henrique Pinto
X-KDE-PluginInfo-Email=henrique.pinto@kdemail.net
X-KDE-PluginInfo-Name=kerfuffle_libarchive
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=BSD
X-KDE-Priority=100
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
Name=kerfuffle_libarchive
Name[ar]=kerfuffle_libarchive
Name[ast]=kerfuffle_libarchive
Name[bg]=kerfuffle_libarchive
Name[bs]=kerfuffle_libarchive
Name[ca]=kerfuffle_libarchive
Name[ca@valencia]=kerfuffle_libarchive
Name[cs]=kerfuffle_libarchive
Name[da]=kerfuffle_libarchive
Name[de]=kerfuffle_libarchive
Name[el]=kerfuffle_libarchive
Name[en_GB]=kerfuffle_libarchive
Name[es]=kerfuffle_libarchive
Name[et]=kerfuffle_libarchive
Name[eu]=kerfuffle_libarchive
Name[fi]=kerfuffle_libarchive
Name[fr]=kerfuffle_libarchive
Name[ga]=kerfuffle_libarchive
Name[gl]=kerfuffle_libarchive
Name[he]=kerfuffle_libarchive
Name[hne]=करफुफल_लिबआर्काइव
Name[hr]=kerfuffle_libarchive
Name[hu]=kerfuffle_libarchive
Name[ia]=kerfuffle_libarchive
Name[id]=kerfuffle_libarchive
Name[it]=kerfuffle_libarchive
Name[ja]=kerfuffle_libarchive
Name[kk]=kerfuffle_libarchive
Name[km]=kerfuffle_libarchive
Name[ko]=kerfuffle_libarchive
Name[lt]=kerfuffle_libarchive
Name[lv]=kerfuffle_libarchive
Name[mr]=कर्फफल_लिब-संग्रह
Name[nb]=kerfuffle_libarchive
Name[nds]=kerfuffle_libarchive
Name[nl]=kerfuffle_libarchive
Name[nn]=kerfuffle_libarchive
Name[pa]=kerfuffle_libarchive
Name[pl]=kerfuffle_libarchive
Name[pt]=kerfuffle_libarchive
Name[pt_BR]=kerfuffle_libarchive
Name[ro]=kerfuffle_libarchive
Name[ru]=kerfuffle_libarchive
Name[sk]=kerfuffle_libarchive
Name[sl]=kerfuffle_libarchive
Name[sq]=kerfuffle_libarchive
Name[sr]=kerfuffle_libarchive
Name[sr@ijekavian]=kerfuffle_libarchive
Name[sr@ijekavianlatin]=kerfuffle_libarchive
Name[sr@latin]=kerfuffle_libarchive
Name[sv]=Kerfuffle Libarchive
Name[ta]=கெர்ஃபஃபில் லிப்ஆர்கைவ்
Name[th]=kerfuffle_libarchive
Name[tr]=kerfuffle_libarchive
Name[uk]=kerfuffle_libarchive
Name[wa]=kerfuffle_libarchive
Name[x-test]=xxkerfuffle_libarchivexx
Name[zh_CN]=kerfuffle_libarchive
Name[zh_TW]=kerfuffle_libarchive
Comment=LibArchive Plugin for Kerfuffle
Comment[ar]=LibArchive ملحق لـ Kerfuffle
Comment[ast]=Aplicación LibArchive pa Kerfuffle
Comment[bg]=Приставка LibArchive за Kerfuffle
Comment[bs]=Priključak libarchive za Kerfafl
Comment[ca]=Connector del LibArchive pel Kerfuffle
Comment[ca@valencia]=Connector del LibArchive pel Kerfuffle
Comment[cs]=LibArchive modul pro Kerfuffle
Comment[da]=LibArchive-plugin til Kerfuffle
Comment[de]=LibArchive-Modul für Kerfuffle
Comment[el]=πρόσθετο LibArchive για τη Kerfuffle
Comment[en_GB]=LibArchive Plugin for Kerfuffle
Comment[es]=Complemento LibArchive para Kerfuffle
Comment[et]=Kerfuffle'i LibArchive plugin
Comment[eu]=Kerfuffle-rentzako LibArchive plugina
Comment[fi]=LibArchive-pakkaustuki
Comment[fr]=Module externe « LibArchive » pour Kerfuffle
Comment[ga]=Breiseán LibArchive le haghaidh Kerfuffle
Comment[gl]=Extensión de libarchive para Kerfuffle
Comment[he]=תוסף LibArchive  עבור Kerfuffle
Comment[hne]=करफुफल बर लिबआर्काइव प्लगइन
Comment[hr]=Priključak LibArchive za Kerfuffle
Comment[hu]=LibArchive Kerfuffle-modul
Comment[ia]=Plugin de Libarchive per Kerfuffle
Comment[id]=Pengaya LibArchive untuk Kerfuffle
Comment[it]=Estensione LibArchive per Kerfuffle
Comment[ja]=Kerfuffle のための LibArchive プラグイン
Comment[kk]=Kerfuffle-ге арналған LibArchive плагині
Comment[km]=កម្មវិធី​ជំនួយ LibArchive សម្រាប់ Kerfuffle
Comment[ko]=Kerfuffle을 위한 LibArchive 플러그인
Comment[lt]=LibArchive Kerfuffle priedas
Comment[lv]=Kerfuffle LibArchive spraudnis
Comment[mr]=कर्फफल करिता लिब-संग्रह प्लगइन
Comment[nb]=LibArchive programtillegg for Kerfuffle
Comment[nds]=LibArchive-Moduul för Kerfuffle
Comment[nl]=LibArchive-plug-in voor Kerfuffle
Comment[nn]=LibArchive-programtillegg til Kerfuffle
Comment[pl]=Wtyczka libArchive dla Kerfuffle
Comment[pt]='Plugin' de LibArchive para o Kerfuffle
Comment[pt_BR]=Plugin LibArchive para a Kerfuffle
Comment[ro]=Modul LibArchive pentru Kerfuffle
Comment[ru]=Модуль LibArchive для Kerfuffle
Comment[sk]=LibArchive modul pre Kerfuffle
Comment[sl]=Vstavek LibArchive za Kerfuffle
Comment[sq]=LibArchive Plugin për Kerfuffle
Comment[sr]=Прикључак libarchive за Керфафл
Comment[sr@ijekavian]=Прикључак libarchive за Керфафл
Comment[sr@ijekavianlatin]=Priključak libarchive za Kerfuffle
Comment[sr@latin]=Priključak libarchive za Kerfuffle
Comment[sv]=Libarchive-insticksprogram för Kerfuffle
Comment[ta]=கெர்ஃபஃபில் க்கு லிப்ஆர்கைவ் சொருகி
Comment[th]=ส่วนเสริมของ Kerfuffle สำหรับใช้งานไลบรารี LibArchive
Comment[tr]=Kerfuffle için LibArchive eklentisi
Comment[uk]=Додаток LibArchive для Kerfuffle
Comment[x-test]=xxLibArchive Plugin for Kerfufflexx
Comment[zh_CN]=Kerfuffle 的 LibArchive 插件
Comment[zh_TW]=Kerfuffle 的 LibArchive 外掛程式
MimeType=@SUPPORTED_LIBARCHIVE_READWRITE_MIMETYPES@
